@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-07-07'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ use Moose;
 use namespace::autoclean;
 
 with (
-    'Dist::Zilla::Role::InstallTool',
+    'Dist::Zilla::Role::AfterBuild',
     'Dist::Zilla::Role::Rinci::CheckDefinesMeta',
 );
 
@@ -51,9 +51,7 @@ sub _prereq_none {
     $num_any == 0;
 }
 
-# actually we use InstallTool phase just so we are run after all the
-# PrereqSources plugins
-sub setup_installer {
+sub after_build {
     my $self = shift;
 
     my $prereqs_hash = $self->zilla->prereqs->as_string_hash;
@@ -84,7 +82,7 @@ Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec - Ensure prereq to spec modul
 
 =head1 VERSION
 
-This document describes version 0.04 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2016-12-28.
+This document describes version 0.05 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2017-07-07.
 
 =head1 SYNOPSIS
 
@@ -124,7 +122,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
